@@ -1,14 +1,13 @@
-# -*- coding: utf-8 -*-
 """Utility code for tests."""
 
 __author__ = 'Jens Finkhaeuser'
-__copyright__ = 'Copyright (c) 2017-2019 Jens Finkhaeuser'
-__license__ = 'MIT +no-false-attribs'
+__copyright__ = 'Copyright (c) 2017-2021 Jens Finkhaeuser'
+__license__ = 'MIT'
 __all__ = ()
 
 import pytest
 
-class Sandboxer(object):
+class Sandboxer:
   """
   Given a sandbox template path, uses pytest to create a temporary directory,
   then copies the template's contents there, and changes to the directory.
